pub struct FentryProgramBytecodeImageImagepullsecret {
pub name: String,
pub namespace: String,
}Expand description
ImagePullSecret is the name of the secret bpfman should use to get remote image repository secrets.
Fields
name: StringName of the secret which contains the credentials to access the image repository.
namespace: StringNamespace of the secret which contains the credentials to access the image repository.