pub struct FexitProgramSpec {
pub bpffunctionname: String,
pub bytecode: FexitProgramBytecode,
pub func_name: String,
pub globaldata: Option<BTreeMap<String, String>>,
pub mapownerselector: Option<FexitProgramMapownerselector>,
pub nodeselector: FexitProgramNodeselector,
}Expand description
FexitProgramSpec defines the desired state of FexitProgram
Fields
bpffunctionname: StringBpfFunctionName is the name of the function that is the entry point for the BPF program
bytecode: FexitProgramBytecodeBytecode configures where the bpf program’s bytecode should be loaded from.
func_name: StringFunction to attach the fexit to.
globaldata: Option<BTreeMap<String, String>>GlobalData allows the user to to set global variables when the program is loaded with an array of raw bytes. This is a very low level primitive. The caller is responsible for formatting the byte string appropriately considering such things as size, endianness, alignment and packing of data structures.
mapownerselector: Option<FexitProgramMapownerselector>MapOwnerSelector is used to select the loaded eBPF program this eBPF program will share a map with. The value is a label applied to the BpfProgram to select. The selector must resolve to exactly one instance of a BpfProgram on a given node or the eBPF program will not load.
nodeselector: FexitProgramNodeselectorNodeSelector allows the user to specify which nodes to deploy the bpf program to. This field must be specified, to select all nodes use standard metav1.LabelSelector semantics and make it empty.