pub struct XdpProgramMapownerselector {
pub match_expressions: Option<Vec<XdpProgramMapownerselectorMatchExpressions>>,
pub match_labels: Option<BTreeMap<String, String>>,
}Expand description
MapOwnerSelector is used to select the loaded eBPF program this eBPF program will share a map with. The value is a label applied to the BpfProgram to select. The selector must resolve to exactly one instance of a BpfProgram on a given node or the eBPF program will not load.
Fields
match_expressions: Option<Vec<XdpProgramMapownerselectorMatchExpressions>>matchExpressions is a list of label selector requirements. The requirements are ANDed.
match_labels: Option<BTreeMap<String, String>>matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is “key”, the operator is “In”, and the values array contains only “value”. The requirements are ANDed.